@@ -12,7 +12,7 @@
 # limitations under the License.
 #
 # $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (三, 09  3 2016) $
+# $Date: 2016-03-09 09:43:46 +0800 (Wed, 09 Mar 2016) $
 # $Revision: 9579 $
 
 from django.db import models
@@ -21,7 +21,7 @@ from Iuppiter.Model import BaseModelMixin
 
 from Theophrastus.models import Newsletter, Contact
 
-class CloudMailInformation(models.Model):
+class CloudMailInformation(models.Model, BaseModelMixin):
     """
     Mail sending information.
     """
@@ -34,7 +34,7 @@ class CloudMailInformation(models.Model):
     # Response message for sent mail.
     message = models.TextField(default='')
 
-class NewsletterInformation(models.Model):
+class NewsletterInformation(models.Model, BaseModelMixin):
 
     newsletter = models.ForeignKey(Newsletter, unique=True)
 
