@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10680 2017-12-26 02:57:55Z David $
+# $Id: views.py 10694 2017-12-29 09:22:09Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-26 10:57:55 +0800 (Tue, 26 Dec 2017) $
-# $Revision: 10680 $
+# $Date: 2017-12-29 17:22:09 +0800 (Fri, 29 Dec 2017) $
+# $Revision: 10694 $
 
 import base64
 from datetime import datetime
@@ -32,9 +32,6 @@ from Iuppiter.Encoding import _unicode
 from Iuppiter.Logging import createDebugLogger
 
 from Theophrastus.integration.service import IntegrationService
-from Theophrastus.integration.models import(
-    AppMailingList, AppNewsletter
-)
 from Theophrastus.statistics.StatisticsHandler import getStatisticsTotalData
 from Theophrastus.statistics.StatisticsHandler import getStatisticsTotalRateData
 from Theophrastus.statistics.StatisticsHandler import getSubscriberHistory
@@ -321,11 +318,6 @@ def mail(request):
             headerSender=headerSender, headerReply=headerReply,
             attachments=attachments, async=async)
         group.newsletters.add(newsletter)
-        AppNewsletter.objects.create(newsletter=newsletter, app=app)
-        AppMailingList.objects.create(
-            mailingList=newsletter.mailing_list,
-            app=app
-        )
 
         logger.debug('[createMail]_SUSSESS: newsletter<%d>' % newsletter.id)
 
