@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: __init__.py 10670 2017-12-23 06:15:34Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (三, 09  3 2016) $
-# $Revision: 9579 $
+# $Author: David $
+# $Date: 2017-12-23 14:15:34 +0800 (Sat, 23 Dec 2017) $
+# $Revision: 10670 $
 
 from django.conf.urls import url, patterns
 
@@ -24,9 +24,4 @@ urlpatterns = patterns('',
         name='Theophrastus.views.getDefaultHeaderText'),
     url(r'^newsletter/footer/text/$', views.getDefaultFooterText,
         name='Theophrastus.views.getDefaultFooterText'),
-
-    url(r'^newsletter/header/turn/$', views.createOrModifyHeader,
-        name='Theophrastus.views.createOrModifyHeader'),
-    url(r'^newsletter/footer/turn/$', views.createOrModifyFooter,
-        name='Theophrastus.views.createOrModifyFooter'),
 )
