@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10696 2017-12-30 15:15:33Z David $
+# $Id: StatisticsHandler.py 10699 2017-12-30 17:59:55Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-30 23:15:33 +0800 (Sat, 30 Dec 2017) $
-# $Revision: 10696 $
+# $Date: 2017-12-31 01:59:55 +0800 (Sun, 31 Dec 2017) $
+# $Revision: 10699 $
 
 from datetime import timedelta, datetime
 
@@ -586,17 +586,21 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     else:
         def _do(info, subscriberCount, testSubscriberCount):
             rates = []
-            newsletter = conditions['newsletter']
+            newsletter = conditions.get('newsletter', None)
+            if newsletter:
+                totalSentNewsletter = ContactMailingStatus.objects.filter(
+                                    newsletter=newsletter, 
+                                    status=ContactMailingStatus.SENT
+                                ).count()   
+            else:
+                totalSentNewsletter = 0
             for i in info:
                 if i in ('unsubscribe', 'deliverie', 'error'):
                     totalValue = subscriberCount
                 elif i == 'sentTest':
                     totalValue = testSubscriberCount
                 else:
-                    totalValue = ContactMailingStatus.objects.filter(
-                                    newsletter=newsletter, 
-                                    status=ContactMailingStatus.SENT
-                                ).count()      
+                    totalValue = totalSentNewsletter 
                 
                 value = percentage(info[i], totalValue, showPercent=False)
                 
